==> apache-camel-3.14.6-src.zip: apache-camel-3.14.6/components/camel-saxon/src/main/java/org/apache/camel/language/xquery/XQueryLanguage.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.language.xquery;

import net.sf.saxon.Configuration;
import org.apache.camel.CamelContext;
import org.apache.camel.Expression;
import org.apache.camel.Predicate;
import org.apache.camel.component.xquery.XQueryBuilder;
import org.apache.camel.spi.PropertyConfigurer;
import org.apache.camel.spi.annotations.Language;
import org.apache.camel.support.LanguageSupport;
import org.apache.camel.support.component.PropertyConfigurerSupport;

@Language("xquery")
public class XQueryLanguage extends LanguageSupport implements PropertyConfigurer {

    private Class<?> resultType;
    private String headerName;
    private Configuration configuration;

    public Class<?> getResultType() {
        return resultType;
    }

    public void setResultType(Class<?> resultType) {
        this.resultType = resultType;
    }

    public String getHeaderName() {
        return headerName;
    }

    public void setHeaderName(String headerName) {
        this.headerName = headerName;
    }

    public Configuration getConfiguration() {
        return configuration;
    }

    public void setConfiguration(Configuration configuration) {
        this.configuration = configuration;
    }

    @Override
    public Predicate createPredicate(String expression) {
        return (Predicate) createExpression(expression, null);
    }

    @Override
    public Expression createExpression(String expression) {
        return createExpression(expression, null);
    }

    @Override
    public Predicate createPredicate(String expression, Object[] properties) {
        return (Predicate) createExpression(expression, properties);
    }

    @Override
    public Expression createExpression(String expression, Object[] properties) {
        expression = loadResource(expression);

        XQueryBuilder builder = XQueryBuilder.xquery(expression);
        configureBuilder(builder, properties);
        return builder;
    }

    protected void configureBuilder(XQueryBuilder builder, Object[] properties) {
        Class<?> clazz = property(Class.class, properties, 0, resultType);
        if (clazz != null) {
            builder.setResultType(clazz);
        }
        String str = property(String.class, properties, 1, headerName);
        if (str != null) {
            builder.setHeaderName(str);
        }
        if (configuration != null) {
            builder.setConfiguration(configuration);
        }
    }

    @Override
    public boolean configure(CamelContext camelContext, Object target, String name, Object value, boolean ignoreCase) {
        if (target != this) {
            throw new IllegalStateException("Can only configure our own instance !");
        }
        switch (ignoreCase ? name.toLowerCase() : name) {
            case "resulttype":
            case "resultType":
                setResultType(PropertyConfigurerSupport.property(camelContext, Class.class, value));
                return true;
            case "headername":
            case "headerName":
                setHeaderName(PropertyConfigurerSupport.property(camelContext, String.class, value));
                return true;
            case "configuration":
            case "Configuration":
                setConfiguration(PropertyConfigurerSupport.property(camelContext, Configuration.class, value));
                return true;
            default:
                return false;
        }
    }

}

==> apache-camel-4.10.9-src.zip: apache-camel-4.10.9/components/camel-saxon/src/main/java/org/apache/camel/language/xquery/XQueryLanguage.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.language.xquery;

import java.util.Map;

import net.sf.saxon.Configuration;
import org.apache.camel.CamelContext;
import org.apache.camel.Expression;
import org.apache.camel.component.xquery.XQueryBuilder;
import org.apache.camel.spi.PropertyConfigurer;
import org.apache.camel.spi.annotations.Language;
import org.apache.camel.support.SingleInputTypedLanguageSupport;
import org.apache.camel.support.component.PropertyConfigurerSupport;

@Language("xquery")
public class XQueryLanguage extends SingleInputTypedLanguageSupport implements PropertyConfigurer {

    private Configuration configuration;

    public Configuration getConfiguration() {
        return configuration;
    }

    /**
     * To use an existing Saxon configuration, instead of default settings.
     */
    public void setConfiguration(Configuration configuration) {
        this.configuration = configuration;
    }

    @Override
    public Expression createExpression(Expression source, String expression, Object[] properties) {
        expression = loadResource(expression);

        XQueryBuilder builder = XQueryBuilder.xquery(expression);
        configureBuilder(builder, properties, source);
        return builder;
    }

    protected void configureBuilder(XQueryBuilder builder, Object[] properties, Expression source) {
        builder.setSource(source);

        Class<?> clazz = property(Class.class, properties, 0, null);
        if (clazz != null) {
            builder.setResultType(clazz);
        }
        Map<String, String> ns = property(Map.class, properties, 2, null);
        if (ns != null && !ns.isEmpty()) {
            builder.setNamespaces(ns);
        }
        if (configuration != null) {
            builder.setConfiguration(configuration);
        }
    }

    @Override
    public boolean configure(CamelContext camelContext, Object target, String name, Object value, boolean ignoreCase) {
        if (target != this) {
            throw new IllegalStateException("Can only configure our own instance !");
        }
        switch (ignoreCase ? name.toLowerCase() : name) {
            case "configuration":
            case "Configuration":
                setConfiguration(PropertyConfigurerSupport.property(camelContext, Configuration.class, value));
                return true;
            default:
                return false;
        }
    }

}
